@@ -47,6 +47,8 @@
  */
 typedef struct gcal_contact* gcal_contact_t;
 
+typedef struct gcal_structured_subvalues *gcal_structured_subvalues_t;
+
 /** Contact entries array. Its used to hold retrieved contacts
  * retrieved from google server.
  */
@@ -57,6 +59,77 @@ struct gcal_contact_array {
 	size_t length;
 };
 
+/** Phone number types allowed by Google API */
+typedef enum {
+	P_INVALID = -1,
+	P_ASSISTANT,
+	P_CALLBACK,
+	P_CAR,
+	P_COMPANY_MAIN,
+	P_FAX,
+	P_HOME,
+	P_HOME_FAX,
+	P_ISDN,
+	P_MAIN,
+	P_MOBILE,
+	P_OTHER,
+	P_OTHER_FAX,
+	P_PAGER,
+	P_RADIO,
+	P_TELEX,
+	P_TTY_TDD,
+	P_WORK,
+	P_WORK_FAX,
+	P_WORK_MOBILE,
+	P_WORK_PAGER,
+	P_ITEMS_COUNT			// must be the last one!
+} gcal_phone_type;
+	
+/** Email types allowed by Google API */
+typedef enum {
+	E_INVALID = -1,
+	E_HOME,
+	E_OTHER,
+	E_WORK,
+	E_ITEMS_COUNT			// must be the last one!
+} gcal_email_type;
+
+/** Address types allowed by Google API */
+typedef enum {
+	A_INVALID = -1,
+	A_HOME,
+	A_WORK,
+	A_OTHER,
+	A_ITEMS_COUNT			// must be the last one!
+} gcal_address_type;
+
+
+/** Address structure, represents each field in structuredPostalAddress (Google API 3.0) */
+/*
+F_AGENT,			not used
+F_HOUSENAME,			not used
+F_STREET,
+F_POBOX,
+F_NEIGHBORHOOD,			not used
+F_CITY,
+F_SUBREGION,			not used
+F_REGION,
+F_POSTCODE,
+F_COUNTRY,
+F_FORMATTEDADDRESS,
+*/
+typedef enum {
+	F_INVALID = -1,
+	F_STREET,
+	F_POBOX,
+	F_CITY,
+	F_REGION,
+	F_POSTCODE,
+	F_COUNTRY,
+	F_FORMATTEDADDRESS,
+	F_ITEMS_COUNT			// must be the last one!
+} gcal_structured_postal_address_fields;
+
 
 /** Creates a new google contact object.
  *
@@ -303,8 +376,12 @@ char gcal_contact_is_deleted(gcal_contact_t contact);
  * atom stream, it will be set to an empty string (i.e. "").
 
  */
-char *gcal_contact_get_email(gcal_contact_t contact);
+int gcal_contact_get_emails_count(gcal_contact_t contact);
+int gcal_contact_get_pref_email(gcal_contact_t contact);
+char *gcal_contact_get_email_address(gcal_contact_t contact, int i);
+gcal_email_type gcal_contact_get_email_address_type(gcal_contact_t contact, int i);
 
+char *gcal_contact_get_email(gcal_contact_t contact);
 /** Access contact description.
  *
  * This the place where contacts notes can be retrieved.
@@ -317,6 +394,14 @@ char *gcal_contact_get_email(gcal_contact_t contact);
  */
 char *gcal_contact_get_content(gcal_contact_t contact);
 
+/** Access contact nickname.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return  Pointer to internal object field
+ */
+char *gcal_contact_get_nickname(gcal_contact_t contact);
+
 /** Access contact organization name.
  *
  *
@@ -351,9 +436,23 @@ char *gcal_contact_get_profission(gcal_contact_t contact);
  */
 char *gcal_contact_get_im(gcal_contact_t contact);
 
-/** Access contact telephone.
+/** Access contact website.
  *
- * \todo Implement support for multiple phones.
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Pointer to internal object field
+ */
+char *gcal_contact_get_homepage(gcal_contact_t contact);
+
+/** Access contact blog.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Pointer to internal object field
+ */
+char *gcal_contact_get_blog(gcal_contact_t contact);
+
+/** Access contact telephone.
  *
  * @param contact A contact object, see \ref gcal_contact.
  *
@@ -362,11 +461,12 @@ char *gcal_contact_get_im(gcal_contact_t contact);
  * atom stream, it will be set to an empty string (i.e. "").
 
  */
-char *gcal_contact_get_phone(gcal_contact_t contact);
+/* TODO: document new functions */
+int gcal_contact_get_phone_numbers_count(gcal_contact_t contact);
+char *gcal_contact_get_phone_number(gcal_contact_t contact, int i);
+gcal_phone_type gcal_contact_get_phone_number_type(gcal_contact_t contact, int i);
 
-/** Access contact telephone.
- *
- * \todo Implement support for multiple addresses.
+/** Access contact address (structuredPostalAddress.formattedAddress).
  *
  * @param contact A contact object, see \ref gcal_contact.
  *
@@ -377,7 +477,83 @@ char *gcal_contact_get_phone(gcal_contact_t contact);
  */
 char *gcal_contact_get_address(gcal_contact_t contact);
 
+/** Access structured entry objects.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Pointer to internal object field
+ */
+/* TODO: document new functions */
+gcal_structured_subvalues_t gcal_contact_get_structured_address(gcal_contact_t contact);
+gcal_structured_subvalues_t gcal_contact_get_structured_name(gcal_contact_t contact);
+
+/** Get one structured entry.
+ *
+ * @param structured_entry A structured entry object, see \ref gcal_structured_subvalues.
+ *
+ * @param structured_entry_nr Index of the entry.
+ *
+ * @param structured_entry_count Number of all entries.
+ *
+ * @param field_key Key of the structured entry.
+ *
+ * @return Pointer to internal object field
+ */
+/* TODO: document new functions */
+char *gcal_contact_get_structured_entry(gcal_structured_subvalues_t structured_entry, int structured_entry_nr, int structured_entry_count, const char *field_key);
+
+/** Access structured entry count.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Number of structured entries
+ * @return Pointer to internal object field
+ */
+/* TODO: document new functions */
+int gcal_contact_get_structured_address_count(gcal_contact_t contact);
+int *gcal_contact_get_structured_address_count_obj(gcal_contact_t contact);
+
+/** Access structured entry type.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param structured_entry_nr The number of the specific entry.
+ *
+ * @param structured_entry_count Number of all entries.
+ *
+ * @return Type of entry
+ * @return Pointer to internal object field
+ */
+gcal_address_type gcal_contact_get_structured_address_type(gcal_contact_t contact, int structured_entry_nr, int structured_entry_count);
+/* TODO: document new functions */
+char ***gcal_contact_get_structured_address_type_obj(gcal_contact_t contact);
+
+/** Access Google group membership info.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Pointer to internal object field (dont free it!) or NULL (in error
+ * case or if the field is not set). If the entry hasn't this field in the
+ * atom stream, it will be set to an empty string (i.e. "").
+
+ */
+int gcal_contact_get_groupMembership_count(gcal_contact_t contact);
+/* TODO: document new functions */
+char *gcal_contact_get_groupMembership(gcal_contact_t contact, int i);
+
+/** Access contact birthday.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @return Pointer to internal object field (dont free it!) or NULL (in error
+ * case or if the field is not set). If the entry hasn't this field in the
+ * atom stream, it will be set to an empty string (i.e. "").
+ */
+char *gcal_contact_get_birthday(gcal_contact_t contact);
+
 /** Access contact photo data.
+ *
+ * When no year is set in Google, Year is set to 1900 in KABC
  *
  * @param contact A contact object, see \ref gcal_contact.
  *
@@ -417,19 +593,28 @@ int gcal_contact_set_title(gcal_contact_t contact, const char *field);
 /** Sets contact email.
  *
  * This field is a hard requirement to create a new contact. Google server
- * supports more e-mails with special tags too, but its not supported
- * for while using gcal_contact object.
+ * supports more e-mails with special tags too.
  *
  * If you need to add a contact entry with all optional fields, an
  * alternative is to use \ref gcal_add_xmlentry.
  *
  * @param contact A contact object, see \ref gcal_contact.
  *
- * @param field String with contact email (e.g. "joe.doe@nobody.com").
+ * @param field Email address..
  *
- * @return 0 for sucess, -1 otherwise.
+ * @param type Email address type.
+ *
+ * @param pref Preferred email address (0=no, 1=yes).
+ *
+ * @return 0 for success, -1 otherwise
  */
-int gcal_contact_set_email(gcal_contact_t contact, const char *field);
+
+int gcal_contact_add_email_address(gcal_contact_t contact, const char *field,
+				   gcal_email_type type, int pref);
+
+/* TODO: document new functions */
+int gcal_contact_delete_email_addresses(gcal_contact_t contact);
+
 
 /** Sets contact edit url.
  *
@@ -482,11 +667,17 @@ int gcal_contact_set_etag(gcal_contact_t contact, const char *field);
  *
  * @param field Phone number.
  *
+ * @param type Phone number type.
+ *
  * @return 0 for success, -1 otherwise
  */
-int gcal_contact_set_phone(gcal_contact_t contact, const char *field);
+int gcal_contact_add_phone_number(gcal_contact_t contact, const char *field,
+				  gcal_phone_type type);
 
-/** Sets the contact address (for while only a single address is supported).
+/* TODO: document new functions */
+int gcal_contact_delete_phone_numbers(gcal_contact_t contact);
+
+/** Sets the contact address (structuredPostalAddress.formattedAddress).
  *
  * \todo Implement multiple address support
  *
@@ -498,6 +689,79 @@ int gcal_contact_set_phone(gcal_contact_t contact, const char *field);
  */
 int gcal_contact_set_address(gcal_contact_t contact, const char *field);
 
+/** Sets the contact full address number (structuredPostalAddress).
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param type Address type.
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_structured_address_nr(gcal_contact_t contact,
+					   gcal_address_type type);
+
+/** Sets a structured entry.
+ *
+ * @param structured_entry A structured entry object, see \ref gcal_structured_subvalues.
+ *
+ * @param structured_entry_nr Index of the entry.
+ *
+ * @param structured_entry_count Number of all entries.
+ *
+ * @param field_key Key of the structured entry.
+ *
+ * @param field_value Corresponding value.
+ *
+ * @param structured_entry_type Structured entry type.
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_structured_entry(gcal_structured_subvalues_t structured_entry,
+				      int structured_entry_nr,
+				      int structured_entry_count,
+				      const char *field_key,
+				      const char *field_value );
+
+/** Deletes a structured entry.
+ *
+ * @param structured_entry A structured entry object, see \ref gcal_structured_subvalues.
+ *
+ * @param *structured_entry_count Pointer to the structured entry count object.
+ *
+ * @param ***structured_entry_type Pointer to the structured entry type object.
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_delete_structured_entry(gcal_structured_subvalues_t structured_entry,
+					 int *structured_entry_count,
+					 char ***structured_entry_type);
+
+/** Sets the contact group membership info.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param field Group name.
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_add_groupMembership(gcal_contact_t contact, char *field);
+
+/* TODO: document new functions */
+int gcal_contact_delete_groupMembership(gcal_contact_t contact);
+
+
+/** Sets the contact birthday
+ *
+ * When no year is set in Google, Year is set to 1900 in KABC
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param field birthday string.
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_birthday(gcal_contact_t contact, const char *field);
+
 /** Sets the organization title.
  *
  *
@@ -521,7 +785,6 @@ int gcal_contact_set_profission(gcal_contact_t contact, const char *field);
 int gcal_contact_set_organization(gcal_contact_t contact, const char *field);
 
 /** Sets contact description.
- *
  *
  * @param contact A contact object, see \ref gcal_contact.
  *
@@ -531,6 +794,37 @@ int gcal_contact_set_organization(gcal_contact_t contact, const char *field);
  */
 int gcal_contact_set_content(gcal_contact_t contact, const char *field);
 
+/** Sets contact nickname.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param field The nickname
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_nickname(gcal_contact_t contact, const char *field);
+
+/** Sets contact website.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param field URL
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_homepage(gcal_contact_t contact, const char *field);
+
+/** Sets contact blog.
+ *
+ * @param contact A contact object, see \ref gcal_contact.
+ *
+ * @param field URL
+ *
+ * @return 0 for success, -1 otherwise
+ */
+int gcal_contact_set_blog(gcal_contact_t contact, const char *field);
+
+/* TODO: document new functions */
 int gcal_contact_set_photo(gcal_contact_t contact, const char *field,
 			   int length);
 
